import os,sys
from datetime import datetime

import csv

class CSVConnection:

    def __init__(self, logger, delimiter):
        self.log = logger
        if not os.path.exists('csv'):
            os.mkdir('csv')
        self.file_path = None
        self.delimiter = delimiter


    def start(self, dir_name, entity):
        file_name = "%s" % entity
        dir_path = 'csv/%s' % dir_name
        if not os.path.exists(dir_path):
            os.mkdir(dir_path)
        absolute_path = os.path.abspath(dir_path)
        timestamp = datetime.now().isoformat().replace(':', '-').split('.')[0]
        file_path = '%s/%s-%s.csv' % (absolute_path, file_name, timestamp)
        try:
            cf = open(file_path, "w", encoding='utf-8')
            cf.close()
        except Exception as e:
            exc_type, exc_msg = sys.exc_info()[:2]
            self.log.error("%s CSVConnection.start unable to create file: %s" % (exc_type, exc_msg))
            raise
        self.file_path = file_path
        return file_path


    def save(self, rows, fields=None):

        try:
            cf = open(self.file_path, "a", encoding='utf-8', newline='')
            writer = csv.writer(cf, delimiter=self.delimiter)
            # if the save is happening in a context where no DB tables will be created/populated, include the header line
            if 'csv/default/' in self.file_path:
                writer.writerow(fields)
            for row in rows:
                row = tuple([x.strip("'") if type(x).__name__ == 'str' else x for x in row])
                writer.writerow(row)
            cf.close()
        except Exception as e:
            exc_type, exc_msg = sys.exc_info()[:2]
            self.log.error("%s CSVConnection.save unable to save AC data to file: %s" % (exc_type, exc_msg))
            raise
        return True

